==> brlcad-7.8.2.tar.bz2: brlcad-7.8.2/src/mged/points/points_parse.h <==
/* A Bison parser, made from points_parse.y, by GNU bison 1.75.  */

/* Skeleton parser for Yacc-like parsing with Bison,
   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002 Free Software Foundation, Inc.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.  */

/* As a special exception, when this file is copied by Bison into a
   Bison output file, you may use that output file without restriction.
   This special exception was added by the Free Software Foundation
   in version 1.24 of Bison.  */

#ifndef BISON_POINTS_PARSE_H
# define BISON_POINTS_PARSE_H

/* Tokens.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
   /* Put the tokens into the symbol table, so that GDB and other debuggers
      know about them.  */
   enum yytokentype {
     COMMA = 258,
     NL = 259,
     COMMENT = 260,
     INT = 261,
     FLT = 262,
     PLATE = 263,
     ARB = 264,
     SYMMETRY = 265,
     POINTS = 266,
     CYL = 267,
     CYLINDER = 268,
     PIPE = 269,
     SPHERE = 270
   };
#endif
#define COMMA 258
#define NL 259
#define COMMENT 260
#define INT 261
#define FLT 262
#define PLATE 263
#define ARB 264
#define SYMMETRY 265
#define POINTS 266
#define CYL 267
#define CYLINDER 268
#define PIPE 269
#define SPHERE 270




#ifndef YYSTYPE
typedef int yystype;
# define YYSTYPE yystype
#endif

extern YYSTYPE yylval;


#endif /* not BISON_POINTS_PARSE_H */

==> brlcad-7.10.4.tar.bz2: brlcad-7.10.4/src/mged/points/points_parse.h <==
/* A Bison parser, made by GNU Bison 1.875c.  */

/* Skeleton parser for Yacc-like parsing with Bison,
   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003 Free Software Foundation, Inc.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.  */

/* As a special exception, when this file is copied by Bison into a
   Bison output file, you may use that output file without restriction.
   This special exception was added by the Free Software Foundation
   in version 1.24 of Bison.  */

/* Tokens.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
   /* Put the tokens into the symbol table, so that GDB and other debuggers
      know about them.  */
   enum yytokentype {
     COMMA = 258,
     NL = 259,
     COMMENT = 260,
     INT = 261,
     FLT = 262,
     PLATE = 263,
     ARB = 264,
     SYMMETRY = 265,
     POINTS = 266,
     CYL = 267,
     CYLINDER = 268,
     PIPE = 269,
     SPHERE = 270
   };
#endif
#define COMMA 258
#define NL 259
#define COMMENT 260
#define INT 261
#define FLT 262
#define PLATE 263
#define ARB 264
#define SYMMETRY 265
#define POINTS 266
#define CYL 267
#define CYLINDER 268
#define PIPE 269
#define SPHERE 270




#if ! defined (YYSTYPE) && ! defined (YYSTYPE_IS_DECLARED)
typedef int YYSTYPE;
# define yystype YYSTYPE /* obsolescent; will be withdrawn */
# define YYSTYPE_IS_DECLARED 1
# define YYSTYPE_IS_TRIVIAL 1
#endif

extern YYSTYPE yylval;
